@@ -7,11 +7,13 @@ from user.model import User
 from user.view import ShelfUserView
 
 class Shelf:
-    def __init__(self, app):
+    model_user = User
+
+    def __init__(self, app, model_user=User):
         if app:
             self.init_app(app)
 
-    def init_app(self, app):
+    def init_app(self, app, model_user=User):
         self.app = app
 
         self.blueprint = Blueprint('shelf', 'shelf', url_prefix="/shelf", 
@@ -27,15 +29,18 @@ class Shelf:
 
         #self.cache = cache.ShelfCache(app, shelf=self)
 
+        if not issubclass(model_user, User):
+            raise ValueError("Your user class must be a subclass of the Shelf User class")
+        self.model_user = model_user
         login = user.login
         login.init_app(app)
-        login.login_view = "admin.signin"
+        #login.login_view = "admin.signin"
         self.login = login
         @self.login.user_loader
         def load_user(userid):
-            return User.query.get(userid)
+            return self.model_user.query.get(userid)
 
-        self.admin.add_view(ShelfUserView(User, db.session))
+        self.admin.add_view(ShelfUserView(self.model_user, db.session))
 
         '''shelf_admin = Blueprint('shelf', 'shelf', url_prefix="/shelf", 
             template_folder="templates", static_folder="static")
